@@ -84,7 +84,7 @@ class Email(DeactivableMixin, ModelSQL, ModelView):
         t = cls.__table__()
         cls._sql_constraints = [
             ('email_list_unique', Unique(t, t.email, t.list_),
-                'marketing.msg_email_list_unique'),
+                'marketing_email.msg_email_list_unique'),
             ]
 
     @classmethod
@@ -135,6 +135,11 @@ class Email(DeactivableMixin, ModelSQL, ModelView):
 
     @classmethod
     def create(cls, vlist):
+        vlist = [v.copy() for v in vlist]
+        for values in vlist:
+            # Ensure to get a different token for each record
+            # default methods are called only once
+            values.setdefault('email_token', cls.default_email_token())
         records = super().create(vlist)
         cls._format_email(records)
         return records
